##  Share Insights with Different Stakeholders
Apart from creating an EA-specific view, you also need to decide which insights and metrics are relevant for other stakeholders who play a key role in the ERP transformation, such as Program and Transformation Managers, CIO, and other management stakeholders, as well as how to present those. You can leverage SAP LeanIX Dashboards to create customized views. To learn more about creating custom Dashboards, see [Create a Custom Dashboard](https://help.sap.com/docs/leanix/ea/dashboards?locale=en-US&state=PRODUCTION&version=CLOUD "Dashboards enable you to consolidate and interpret data in one place, facilitating informed decision-making and promoting efficient task management. Learn how to create, customize, and manage dashboards.").
Here are some best practices to consider:
  * Align with the leadership and change organization early on on the KPIs and views they are interested in, based on what is possible with SAP LeanIX.
  * Define a format and cadence of how to present these KPIs; make sure to fit in the existing structure of the transformation program instead of creating parallel formats.
  * Create different SAP LeanIX Dashboards and saved Reports for different audiences, e.g.,:
    * One high-level dashboard for all key stakeholders involved in the transformation program (adequate for C-Level and Program Manager)
    * Dashboard for the EA core team
    * Dashboard for Project Managers
  * Keep in mind that your stakeholders might not use SAP LeanIX on a daily basis. How can you engage the leadership and change the organization to go into the tool? Make sure that they understand the views that they will get, e.g., by having a well-structured dashboard with explanations on the landing page. Or sending them direct links to a specific (pre-filtered) Report.
  * Engage your stakeholders in discussions, focusing on eye-opening insights that they need.
  * Get approval and backing by ensuring that about 90% of your business stakeholders have seen and acknowledged your insights.
